==> imsdk_client_flutter-0.0.7.tar.gz: lib/app/session_redpack.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart';

import 'app_config.dart';
import 'app_locale.dart';

///
///发送红包
///
class SessionRedpack extends StatefulWidget {
  ///当前会话sid
  final ObjectId sid;

  const SessionRedpack({Key? key, required this.sid}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _SessionRedpackSendState();
}

class _SessionRedpackSendState extends State<SessionRedpack> {
  static const _textFieldLabelOffsetY = 2.0;
  static const _sureButtonHeight = 58.0;

  bool _normal = true; //是否为普通红包

  final _valueController = TextEditingController(text: '0.00'); //保留一个空格，不然无焦点时首尾标签不显示
  final _countController = TextEditingController(text: '1'); //保留一个空格，不然无焦点时首尾标签不显示
  final _descController = TextEditingController();

  @override
  void initState() {
    super.initState();
    AppConfig.logDebug(['SessionRedpack.initState()']);
  }

  @override
  void dispose() {
    AppConfig.logDebug(['SessionRedpack.dispose()']);
    _valueController.dispose();
    _countController.dispose();
    _descController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    final backgroundColor = themeData.brightness == Brightness.light ? Colors.grey[200] : null; //增强light状态white气泡的对比度
    return Scaffold(
      resizeToAvoidBottomInset: false,
      backgroundColor: backgroundColor,
      appBar: AppBar(
        backgroundColor: backgroundColor,
        title: Text(_normal ? AppLocalizations.sessionRedpackTitleNormal : AppLocalizations.sessionRedpackTitleLuckly),
      ),
      body: ListView(
        physics: AppConfig.bodyGlobalScrollPhysics,
        padding: AppConfig.bodyGlobalPadding,
        children: [
          TextFormField(
            controller: _valueController,
            keyboardType: const TextInputType.numberWithOptions(decimal: true),
            textInputAction: TextInputAction.next,
            textAlign: TextAlign.right,
            maxLength: 12,
            maxLines: 1,
            decoration: InputDecoration(
              filled: true,
              fillColor: themeData.cardColor,
              enabledBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              focusedBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              contentPadding: AppConfig.bodyGlobalPadding,
              prefixIconConstraints: const BoxConstraints(),
              suffixIconConstraints: const BoxConstraints(),
              prefixIcon: Padding(
                padding: EdgeInsets.only(left: AppConfig.bodyGlobalPadding.left, bottom: _textFieldLabelOffsetY),
                child: Text(_normal ? AppLocalizations.sessionRedpackTextSingleMoney : AppLocalizations.sessionRedpackTextTotalMoney, style: themeData.textTheme.subtitle1),
              ),
              suffixIcon: Padding(
                padding: EdgeInsets.only(right: AppConfig.bodyGlobalPadding.right, bottom: _textFieldLabelOffsetY),
                child: Text(AppLocalizations.sessionRedpackTextUnitMoney, style: themeData.textTheme.subtitle1),
              ),
              hintText: AppLocalizations.sessionRedpackHintMoney,
              counterText: '',
            ),
          ),
          Row(
            children: <Widget>[
              SizedBox(width: AppConfig.bodyGlobalPadding.left),
              Text(AppLocalizations.sessionRedpackTextSwitchTo, style: themeData.textTheme.bodyText2),
              TextButton(
                child: Text(_normal ? AppLocalizations.sessionRedpackTitleLuckly : AppLocalizations.sessionRedpackTitleNormal, style: themeData.textTheme.bodyText2?.copyWith(color: Colors.orange)),
                onPressed: () {
                  if (mounted) {
                    setState(() {
                      _normal = !_normal;
                    });
                  }
                },
              ),
            ],
          ),
          TextFormField(
            controller: _countController,
            keyboardType: TextInputType.number,
            textInputAction: TextInputAction.next,
            textAlign: TextAlign.right,
            maxLength: 4,
            maxLines: 1,
            decoration: InputDecoration(
              filled: true,
              fillColor: themeData.cardColor,
              enabledBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              focusedBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              contentPadding: AppConfig.bodyGlobalPadding,
              prefixIconConstraints: const BoxConstraints(),
              suffixIconConstraints: const BoxConstraints(),
              prefixIcon: Padding(
                padding: EdgeInsets.only(left: AppConfig.bodyGlobalPadding.left, bottom: _textFieldLabelOffsetY),
                child: Text(AppLocalizations.sessionRedpackTextTotalCount, style: themeData.textTheme.subtitle1),
              ),
              suffixIcon: Padding(
                padding: EdgeInsets.only(right: AppConfig.bodyGlobalPadding.right, bottom: _textFieldLabelOffsetY),
                child: Text(AppLocalizations.sessionRedpackTextUnitCount, style: themeData.textTheme.subtitle1),
              ),
              hintText: AppLocalizations.sessionRedpackHintCount,
              counterText: '',
            ),
          ),
          const SizedBox(height: 38),
          TextFormField(
            controller: _descController,
            keyboardType: TextInputType.text,
            textInputAction: TextInputAction.next,
            maxLength: 32,
            maxLines: 1,
            decoration: InputDecoration(
              filled: true,
              fillColor: themeData.cardColor,
              enabledBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              focusedBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              contentPadding: AppConfig.bodyGlobalPadding,
              hintText: AppLocalizations.sessionRedpackHintDesc,
            ),
          ),
          const SizedBox(height: 18),
          ElevatedButton(
            style: ElevatedButton.styleFrom(minimumSize: const Size(double.infinity, _sureButtonHeight), primary: Colors.red),
            onPressed: _onSureBtnPressed,
            child: Text(AppLocalizations.sessionRedpackButtonSure),
          ),
        ],
      ),
    );
  }

  void _onSureBtnPressed() {
    FocusScope.of(context).unfocus();
    String value = _valueController.text.replaceAll(' ', '');
    String count = _countController.text.replaceAll(' ', '');
    String desc = _descController.text.trim();
    if (!RegExp(r'^[0-9]{1,}[\x2E]{0,1}[0-9]{0,2}$').hasMatch(value)) {
      SmartDialog.showToast(AppLocalizations.sessionRedpackErrorMoney);
      return;
    }
    if (!RegExp(r'^[0-9]{1,}$').hasMatch(count)) {
      SmartDialog.showToast(AppLocalizations.sessionRedpackErrorCount);
      return;
    }
    int resValue = (double.parse(value) * 100).toInt() * (_normal ? int.parse(count) : 1);
    int resCount = int.parse(count);
    String resDesc = desc == '' ? AppLocalizations.sessionRedpackHintDesc : desc;
    AppConfig.logInfo(['_onSureBtnPressed=>', resValue, resCount, resDesc]);
  }
}

==> imsdk_client_flutter-0.0.11.tar.gz: lib/app/session_redpack.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart';

import 'app_config.dart';
import 'app_locale.dart';

///
///发送红包
///
class SessionRedpack extends StatefulWidget {
  ///当前会话sid
  final ObjectId sid;

  const SessionRedpack({Key? key, required this.sid}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _SessionRedpackSendState();
}

class _SessionRedpackSendState extends State<SessionRedpack> {
  static const _textFieldLabelOffsetY = 2.0;
  static const _sureButtonHeight = 58.0;

  bool _normal = true; //是否为普通红包

  final _valueController = TextEditingController(text: '0.00'); //保留一个空格，不然无焦点时首尾标签不显示
  final _countController = TextEditingController(text: '1'); //保留一个空格，不然无焦点时首尾标签不显示
  final _descController = TextEditingController();

  @override
  void initState() {
    super.initState();
    AppConfig.logDebug(['SessionRedpack.initState()']);
  }

  @override
  void dispose() {
    AppConfig.logDebug(['SessionRedpack.dispose()']);
    _valueController.dispose();
    _countController.dispose();
    _descController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    final backgroundColor = themeData.brightness == Brightness.light ? Colors.grey[200] : null; //增强light状态white气泡的对比度
    return Scaffold(
      resizeToAvoidBottomInset: false,
      backgroundColor: backgroundColor,
      appBar: AppBar(
        backgroundColor: backgroundColor,
        title: Text(_normal ? AppLocalizations.sessionRedpackTitleNormal : AppLocalizations.sessionRedpackTitleLuckly),
      ),
      body: ListView(
        physics: AppConfig.globalScrollPhysics,
        padding: AppConfig.bodyGlobalPaddingMedium,
        children: [
          TextFormField(
            controller: _valueController,
            keyboardType: const TextInputType.numberWithOptions(decimal: true),
            textInputAction: TextInputAction.next,
            textAlign: TextAlign.right,
            maxLength: 12,
            maxLines: 1,
            decoration: InputDecoration(
              filled: true,
              fillColor: themeData.cardColor,
              enabledBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              focusedBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              contentPadding: AppConfig.bodyGlobalPaddingMedium,
              prefixIconConstraints: const BoxConstraints(),
              suffixIconConstraints: const BoxConstraints(),
              prefixIcon: Padding(
                padding: EdgeInsets.only(left: AppConfig.bodyGlobalPaddingMedium.left, bottom: _textFieldLabelOffsetY),
                child: Text(_normal ? AppLocalizations.sessionRedpackTextSingleMoney : AppLocalizations.sessionRedpackTextTotalMoney, style: themeData.textTheme.subtitle1),
              ),
              suffixIcon: Padding(
                padding: EdgeInsets.only(right: AppConfig.bodyGlobalPaddingMedium.right, bottom: _textFieldLabelOffsetY),
                child: Text(AppLocalizations.sessionRedpackTextUnitMoney, style: themeData.textTheme.subtitle1),
              ),
              hintText: AppLocalizations.sessionRedpackHintMoney,
              counterText: '',
            ),
          ),
          Row(
            children: <Widget>[
              SizedBox(width: AppConfig.bodyGlobalPaddingMedium.left),
              Text(AppLocalizations.sessionRedpackTextSwitchTo, style: themeData.textTheme.bodyText2),
              TextButton(
                child: Text(_normal ? AppLocalizations.sessionRedpackTitleLuckly : AppLocalizations.sessionRedpackTitleNormal, style: themeData.textTheme.bodyText2?.copyWith(color: Colors.orange)),
                onPressed: () {
                  if (mounted) {
                    setState(() {
                      _normal = !_normal;
                    });
                  }
                },
              ),
            ],
          ),
          TextFormField(
            controller: _countController,
            keyboardType: TextInputType.number,
            textInputAction: TextInputAction.next,
            textAlign: TextAlign.right,
            maxLength: 4,
            maxLines: 1,
            decoration: InputDecoration(
              filled: true,
              fillColor: themeData.cardColor,
              enabledBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              focusedBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              contentPadding: AppConfig.bodyGlobalPaddingMedium,
              prefixIconConstraints: const BoxConstraints(),
              suffixIconConstraints: const BoxConstraints(),
              prefixIcon: Padding(
                padding: EdgeInsets.only(left: AppConfig.bodyGlobalPaddingMedium.left, bottom: _textFieldLabelOffsetY),
                child: Text(AppLocalizations.sessionRedpackTextTotalCount, style: themeData.textTheme.subtitle1),
              ),
              suffixIcon: Padding(
                padding: EdgeInsets.only(right: AppConfig.bodyGlobalPaddingMedium.right, bottom: _textFieldLabelOffsetY),
                child: Text(AppLocalizations.sessionRedpackTextUnitCount, style: themeData.textTheme.subtitle1),
              ),
              hintText: AppLocalizations.sessionRedpackHintCount,
              counterText: '',
            ),
          ),
          const SizedBox(height: 38),
          TextFormField(
            controller: _descController,
            keyboardType: TextInputType.text,
            textInputAction: TextInputAction.next,
            maxLength: 32,
            maxLines: 1,
            decoration: InputDecoration(
              filled: true,
              fillColor: themeData.cardColor,
              enabledBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              focusedBorder: themeData.inputDecorationTheme.border!.copyWith(borderSide: BorderSide(color: themeData.cardColor)),
              contentPadding: AppConfig.bodyGlobalPaddingMedium,
              hintText: AppLocalizations.sessionRedpackHintDesc,
            ),
          ),
          const SizedBox(height: 18),
          ElevatedButton(
            style: ElevatedButton.styleFrom(minimumSize: const Size(double.infinity, _sureButtonHeight), primary: Colors.red),
            onPressed: _onSureBtnPressed,
            child: Text(AppLocalizations.sessionRedpackButtonSure),
          ),
        ],
      ),
    );
  }

  void _onSureBtnPressed() {
    FocusScope.of(context).unfocus();
    String value = _valueController.text.replaceAll(' ', '');
    String count = _countController.text.replaceAll(' ', '');
    String desc = _descController.text.trim();
    if (!RegExp(r'^[0-9]{1,}[\x2E]{0,1}[0-9]{0,2}$').hasMatch(value)) {
      SmartDialog.showToast(AppLocalizations.sessionRedpackErrorMoney);
      return;
    }
    if (!RegExp(r'^[0-9]{1,}$').hasMatch(count)) {
      SmartDialog.showToast(AppLocalizations.sessionRedpackErrorCount);
      return;
    }
    int resValue = (double.parse(value) * 100).toInt() * (_normal ? int.parse(count) : 1);
    int resCount = int.parse(count);
    String resDesc = desc == '' ? AppLocalizations.sessionRedpackHintDesc : desc;
    AppConfig.logInfo(['_onSureBtnPressed=>', resValue, resCount, resDesc]);
  }
}
